<?php

namespace App\Http\Controllers\Master\AccountMaster;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

use Auth;
use DB;
use Storage;
use Session;
use Carbon\Carbon;
use App\Services\Utils;
// use App\StaffAndSalesman;
use App\AccountMaster;
use App\AccountMastersAccountsDetail;
use App\AllCountries;
use App\User;
use App\Location;
use App\LocationPermission;
use App\ClassOfAccount;
use App\AccountMasterTrack;
use Illuminate\Support\Facades\Hash;

class StaffAndSalesmanController extends Controller
{

    protected $utils;

    public function __construct(Utils $utils)
    {
        $this->utils = $utils;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $user = Auth::user();
        if (!$user->can('staff-and-salesmen-account-master')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $staff_and_salesmen = AccountMaster::Where('location_id', $location_id)->Where('account_master_type', "Staff-And-Salesman")->orderBy('created_at','DESC')->paginate(100);
        $count = [];
        foreach ($staff_and_salesmen as $account) {
            $account_detail = AccountMastersAccountsDetail::Where('account_master_id', $account->id)->where('voucher_type', '!=' ,"opening balance")->get();
            $count[] = count($account_detail);
        }
        return view('user.masters.account_masters.staff_and_salesmen.index', compact('staff_and_salesmen', 'count'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $user = Auth::user();
        if (!$user->can('staff-and-salesmen-account-master')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $country = Location::where('id', $location_id)->first();
        $class_of_accounts = ClassOfAccount::all();
        $users = LocationPermission::with('users')->where('country_id', $country->country_id)->where('location_id', $location_id)->where('user_id', '!=', $user->id)->get();
        $all_countries = AllCountries::all();
        return view('user.masters.account_masters.staff_and_salesmen.create', compact('all_countries', 'class_of_accounts', 'users'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // dd($request->all());
        $location_id = $this->getLocationId();
        $staff_and_salesman = AccountMaster::Where('first_name', $request->first_name)->Where('account_master_type', "Staff-And-Salesman")->where('location_id', $location_id)->first();
        if ($staff_and_salesman) {
            Session::flash('alert-danger', 'This Staff Already Exists');
            return redirect()->back();
        }
        $staff_and_salesman = new AccountMaster();
        $staff_and_salesman->location_id = $location_id;
        $staff_and_salesman->account_master_type = "Staff-And-Salesman";
        if ($request->transactions_password != "") {
        $staff_and_salesman->transactions_password = Hash::make($request->transactions_password);
        }
        if ($request->report_password != "") {
        $staff_and_salesman->report_password = Hash::make($request->report_password);
        }
        $staff_and_salesman->name_of_organisation = $request->first_name." ".$request->last_name;
        $staff_and_salesman->job_designation = $request->job_designation;
        $staff_and_salesman->job_title = $request->job_title ? $request->job_title : $request->job_designation;
        $staff_and_salesman->commission = $request->commission;
        $staff_and_salesman->date_of_joining = $request->date_of_joining;
        $staff_and_salesman->first_name = $request->first_name;
        $staff_and_salesman->last_name = $request->last_name;
        $staff_and_salesman->mobile_1 = $request->mobile_1;
        $staff_and_salesman->mobile_2 = $request->mobile_2;
        $staff_and_salesman->whatsapp = $request->whatsapp;
        $staff_and_salesman->email = $request->email;
        $staff_and_salesman->country_id = $request->country_id;
        $staff_and_salesman->city = $request->city;
        $staff_and_salesman->address = $request->address;
        $staff_and_salesman->salary = $request->salary;
        $staff_and_salesman->class_of_account_id = $request->class_of_account_id;
        // $staff_and_salesman->show_user = $request->show_user;
        $staff_and_salesman->maintain_account = $request->maintain_account;
        $staff_and_salesman->doc_name_1 = $request->doc_name_1;
        if ($request->hasFile('doc_file_1')) {
            $file = $request->file('doc_file_1');
            $filePath = time() . '-' . $this->utils->randstr() . '.' . $file->getClientOriginalExtension();
            $file->move(public_path('/user_files/img/staff_and_salesman_doc/'), $filePath);
            $staff_and_salesman-> doc_file_1 = $filePath;
        }
        $staff_and_salesman->doc_expiry_1 = $request->doc_expiry_1;

        $staff_and_salesman->doc_name_2 = $request->doc_name_2;
        if ($request->hasFile('doc_file_2')) {
            $file = $request->file('doc_file_2');
            $filePath = time() . '-' . $this->utils->randstr() . '.' . $file->getClientOriginalExtension();
            $file->move(public_path('/user_files/img/staff_and_salesman_doc/'), $filePath);
            $staff_and_salesman-> doc_file_2 = $filePath;
        }
        $staff_and_salesman->doc_expiry_2 = $request->doc_expiry_2;

        $staff_and_salesman->doc_name_3 = $request->doc_name_3;
        if ($request->hasFile('doc_file_3')) {
            $file = $request->file('doc_file_3');
            $filePath = time() . '-' . $this->utils->randstr() . '.' . $file->getClientOriginalExtension();
            $file->move(public_path('/user_files/img/staff_and_salesman_doc/'), $filePath);
            $staff_and_salesman-> doc_file_3 = $filePath;
        }
        $staff_and_salesman->doc_expiry_3 = $request->doc_expiry_3;

        $staff_and_salesman->doc_name_4 = $request->doc_name_4;
        if ($request->hasFile('doc_file_4')) {
            $file = $request->file('doc_file_4');
            $filePath = time() . '-' . $this->utils->randstr() . '.' . $file->getClientOriginalExtension();
            $file->move(public_path('/user_files/img/staff_and_salesman_doc/'), $filePath);
            $staff_and_salesman-> doc_file_4 = $filePath;
        }
        $staff_and_salesman->doc_expiry_4 = $request->doc_expiry_4;

        $staff_and_salesman->doc_name_5 = $request->doc_name_5;
        if ($request->hasFile('doc_file_5')) {
            $file = $request->file('doc_file_5');
            $filePath = time() . '-' . $this->utils->randstr() . '.' . $file->getClientOriginalExtension();
            $file->move(public_path('/user_files/img/staff_and_salesman_doc/'), $filePath);
            $staff_and_salesman-> doc_file_5 = $filePath;
        }
        $staff_and_salesman->doc_expiry_5 = $request->doc_expiry_5;

        $staff_and_salesman->doc_name_6 = $request->doc_name_6;
        if ($request->hasFile('doc_file_6')) {
            $file = $request->file('doc_file_6');
            $filePath = time() . '-' . $this->utils->randstr() . '.' . $file->getClientOriginalExtension();
            $file->move(public_path('/user_files/img/staff_and_salesman_doc/'), $filePath);
            $staff_and_salesman-> doc_file_6 = $filePath;
        }
        $staff_and_salesman->doc_expiry_6 = $request->doc_expiry_6;


        $staff_and_salesman->doc_name_7 = $request->doc_name_7;
        if ($request->hasFile('doc_file_7')) {
            $file = $request->file('doc_file_7');
            $filePath = time() . '-' . $this->utils->randstr() . '.' . $file->getClientOriginalExtension();
            $file->move(public_path('/user_files/img/staff_and_salesman_doc/'), $filePath);
            $staff_and_salesman-> doc_file_7 = $filePath;
        }
        $staff_and_salesman->doc_expiry_7 = $request->doc_expiry_7;

        $staff_and_salesman->description = $request->description;
        $staff_and_salesman->save();
        $current_staff_and_salesman_id = $staff_and_salesman->id;

        if(isset($request->show_user)){
            foreach ($request->show_user as $key => $request->show_user) {
                $account_master_track = new AccountMasterTrack();
                $account_master_track->user_id = $request->show_user;
                $account_master_track->account_master_id = $current_staff_and_salesman_id;
                $account_master_track->account_master_name = "Staff-And-Salesman";
                $account_master_track->save();
            }
        }

        if(Auth::user()->hasRole('super-admin'))
        {
            $account_master_track = new AccountMasterTrack();
            $account_master_track->user_id = Auth::user()->id;
            $account_master_track->account_master_id = $current_staff_and_salesman_id;
            $account_master_track->account_master_name = "Staff-And-Salesman";
            $account_master_track->save();
        }else{
            $admins = User::role('super-admin')->get();
            foreach ($admins as $key => $admin) {
                $account_master_track = new AccountMasterTrack();
                $account_master_track->user_id = $admin->id;
                $account_master_track->account_master_id = $current_staff_and_salesman_id;
                $account_master_track->account_master_name = "Staff-And-Salesman";
                $account_master_track->save();
            }
            $account_master_track = new AccountMasterTrack();
            $account_master_track->user_id = Auth::user()->id;
            $account_master_track->account_master_id = $current_staff_and_salesman_id;
            $account_master_track->account_master_name = "Staff-And-Salesman";
            $account_master_track->save();
        }

        Session::flash('alert-success', 'StaffAndSalesman created successfully');
        return redirect('/masters/account-masters/staff-and-salesmen');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\StaffAndSalesman  $staff_and_salesman
     * @return \Illuminate\Http\Response
     */
    public function show(StaffAndSalesman $staff_and_salesman)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\StaffAndSalesman  $staff_and_salesman
     * @return \Illuminate\Http\Response
     */
    public function edit($staff_and_salesman_id)
    {
        $user = Auth::user();
        if (!$user->can('staff-and-salesmen-account-master')) {
            abort(403, 'Unauthorized action.');
        }

        $location_id = $this->getLocationId();
        $country = Location::where('id', $location_id)->first();
        $class_of_accounts = ClassOfAccount::all();
        $users = LocationPermission::with('users')->where('country_id', $country->country_id)->where('location_id', $location_id)->where('user_id', '!=', $user->id)->get();
        $account_master_track = AccountMasterTrack::Where('account_master_id', $staff_and_salesman_id)
                                                    ->Where('account_master_name', "Staff-And-Salesman")->pluck('user_id');
        $all_countries = AllCountries::all();
        $staff_and_salesman = AccountMaster::Where('id', $staff_and_salesman_id)->Where('account_master_type', "Staff-And-Salesman")->first();
        return view('user.masters.account_masters.staff_and_salesmen.edit', compact('staff_and_salesman', 'all_countries', 'class_of_accounts', 'users', 'account_master_track'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\StaffAndSalesman  $staff_and_salesman
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $staff_and_salesman_id)
    {

        $staff_and_salesman = AccountMaster::Where('id', $staff_and_salesman_id)->Where('account_master_type', "Staff-And-Salesman")->first();
        if ($request->transactions_password != "") {
        $staff_and_salesman->transactions_password = Hash::make($request->transactions_password) ? Hash::make($request->transactions_password) : $staff_and_salesman->transactions_password;
        }
        if ($request->report_password != "") {
        $staff_and_salesman->report_password = Hash::make($request->report_password) ? Hash::make($request->report_password) : $staff_and_salesman->report_password;
        }
        $staff_and_salesman->job_designation = $request->job_designation;
        $staff_and_salesman->job_title = $request->job_title ? $request->job_title : $request->job_designation;
        $staff_and_salesman->commission = $request->commission;
        $staff_and_salesman->date_of_joining = $request->date_of_joining;
        $staff_and_salesman->first_name = $request->first_name;
        $staff_and_salesman->last_name = $request->last_name;
        $staff_and_salesman->name_of_organisation = $request->first_name." ".$request->last_name;
        $staff_and_salesman->mobile_1 = $request->mobile_1;
        $staff_and_salesman->mobile_2 = $request->mobile_2;
        $staff_and_salesman->whatsapp = $request->whatsapp;
        $staff_and_salesman->email = $request->email;
        $staff_and_salesman->country_id = $request->country_id;
        $staff_and_salesman->city = $request->city;
        $staff_and_salesman->address = $request->address;
        $staff_and_salesman->salary = $request->salary;
        $staff_and_salesman->class_of_account_id = $request->class_of_account_id;
        // $staff_and_salesman->show_user = $request->show_user;
        $staff_and_salesman->maintain_account = $request->maintain_account;
        $staff_and_salesman->doc_name_1 = $request->doc_name_1;
        if ($request->hasFile('doc_file_1')) {
            $file = $request->file('doc_file_1');
            $filePath = time() . '-' . $this->utils->randstr() . '.' . $file->getClientOriginalExtension();
            $file->move(public_path('/user_files/img/staff_and_salesman_doc/'), $filePath);
            $staff_and_salesman-> doc_file_1 = $filePath;
        }
        $staff_and_salesman->doc_expiry_1 = $request->doc_expiry_1;

        $staff_and_salesman->doc_name_2 = $request->doc_name_2;
        if ($request->hasFile('doc_file_2')) {
            $file = $request->file('doc_file_2');
            $filePath = time() . '-' . $this->utils->randstr() . '.' . $file->getClientOriginalExtension();
            $file->move(public_path('/user_files/img/staff_and_salesman_doc/'), $filePath);
            $staff_and_salesman-> doc_file_2 = $filePath;
        }
        $staff_and_salesman->doc_expiry_2 = $request->doc_expiry_2;

        $staff_and_salesman->doc_name_3 = $request->doc_name_3;
        if ($request->hasFile('doc_file_3')) {
            $file = $request->file('doc_file_3');
            $filePath = time() . '-' . $this->utils->randstr() . '.' . $file->getClientOriginalExtension();
            $file->move(public_path('/user_files/img/staff_and_salesman_doc/'), $filePath);
            $staff_and_salesman-> doc_file_3 = $filePath;
        }
        $staff_and_salesman->doc_expiry_3 = $request->doc_expiry_3;

        $staff_and_salesman->doc_name_4 = $request->doc_name_4;
        if ($request->hasFile('doc_file_4')) {
            $file = $request->file('doc_file_4');
            $filePath = time() . '-' . $this->utils->randstr() . '.' . $file->getClientOriginalExtension();
            $file->move(public_path('/user_files/img/staff_and_salesman_doc/'), $filePath);
            $staff_and_salesman-> doc_file_4 = $filePath;
        }
        $staff_and_salesman->doc_expiry_4 = $request->doc_expiry_4;

        $staff_and_salesman->doc_name_5 = $request->doc_name_5;
        if ($request->hasFile('doc_file_5')) {
            $file = $request->file('doc_file_5');
            $filePath = time() . '-' . $this->utils->randstr() . '.' . $file->getClientOriginalExtension();
            $file->move(public_path('/user_files/img/staff_and_salesman_doc/'), $filePath);
            $staff_and_salesman-> doc_file_5 = $filePath;
        }
        $staff_and_salesman->doc_expiry_5 = $request->doc_expiry_5;

        $staff_and_salesman->doc_name_6 = $request->doc_name_6;
        if ($request->hasFile('doc_file_6')) {
            $file = $request->file('doc_file_6');
            $filePath = time() . '-' . $this->utils->randstr() . '.' . $file->getClientOriginalExtension();
            $file->move(public_path('/user_files/img/staff_and_salesman_doc/'), $filePath);
            $staff_and_salesman-> doc_file_6 = $filePath;
        }
        $staff_and_salesman->doc_expiry_6 = $request->doc_expiry_6;


        $staff_and_salesman->doc_name_7 = $request->doc_name_7;
        if ($request->hasFile('doc_file_7')) {
            $file = $request->file('doc_file_7');
            $filePath = time() . '-' . $this->utils->randstr() . '.' . $file->getClientOriginalExtension();
            $file->move(public_path('/user_files/img/staff_and_salesman_doc/'), $filePath);
            $staff_and_salesman-> doc_file_7 = $filePath;
        }
        $staff_and_salesman->doc_expiry_7 = $request->doc_expiry_7;

        $staff_and_salesman->description = $request->description;
        $staff_and_salesman->save();

        $account_master_track = AccountMasterTrack::Where('account_master_id', $staff_and_salesman_id)
                                                    ->Where('account_master_name', "Staff-And-Salesman")->get();
        foreach ($account_master_track as $item) {
            $item->delete();
        }
        if(isset($request->show_user)){
            foreach ($request->show_user as $key => $request->show_user) {
                $account_master_track = new AccountMasterTrack();
                $account_master_track->user_id = $request->show_user;
                $account_master_track->account_master_id = $staff_and_salesman_id;
                $account_master_track->account_master_name = "Staff-And-Salesman";
                $account_master_track->save();
            }
        }

        if(Auth::user()->hasRole('super-admin'))
        {
            $account_master_track = new AccountMasterTrack();
            $account_master_track->user_id = Auth::user()->id;
            $account_master_track->account_master_id = $staff_and_salesman_id;
            $account_master_track->account_master_name = "Staff-And-Salesman";
            $account_master_track->save();
        }else{
            $admins = User::role('super-admin')->get();
            foreach ($admins as $key => $admin) {
                $account_master_track = new AccountMasterTrack();
                $account_master_track->user_id = $admin->id;
                $account_master_track->account_master_id = $staff_and_salesman_id;
                $account_master_track->account_master_name = "Staff-And-Salesman";
                $account_master_track->save();
            }
            $account_master_track = new AccountMasterTrack();
            $account_master_track->user_id = Auth::user()->id;
            $account_master_track->account_master_id = $staff_and_salesman_id;
            $account_master_track->account_master_name = "Staff-And-Salesman";
            $account_master_track->save();
        }

        Session::flash('alert-success', 'StaffAndSalesman updated successfully');
        return redirect('/masters/account-masters/staff-and-salesmen');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\StaffAndSalesman  $staff_and_salesman
     * @return \Illuminate\Http\Response
     */
    public function destroy($staff_and_salesman_id)
    {
        $staff_and_salesman = AccountMaster::Where('id', $staff_and_salesman_id)->Where('account_master_type', "Staff-And-Salesman")->first();
        $staff_and_salesman->delete();

        $account_master_track = AccountMasterTrack::Where('account_master_id', $staff_and_salesman_id)
                                                    ->Where('account_master_name', "staff-And-Salesman")->get();
        foreach ($account_master_track as $item) {
            $item->delete();
        }

        Session::flash('alert-success', 'StaffAndSalesman deleted successfully');
        return redirect('/masters/account-masters/staff-and-salesmen');
    }

    public function softdelete($staff_and_salesman_id)
    {
        $staff_and_salesman = AccountMaster::Where('id', $staff_and_salesman_id)->Where('account_master_type', "Staff-And-Salesman")->first();
        $staff_and_salesman->forceDelete();

        $account_master_track = AccountMasterTrack::Where('account_master_id', $staff_and_salesman_id)
                                                    ->Where('account_master_name', "staff-And-Salesman")->get();
        foreach ($account_master_track as $item) {
            $item->forceDelete();
        }

        Session::flash('alert-success', 'StaffAndSalesman deleted successfully');
        return redirect('/masters/account-masters/staff-and-salesmen');
    }
}
