@extends('layouts.master_user')
@section('page-title')
Sales Invoice
@endsection
@section('css')
<style>
    .table-responsive {
        display: block;
        width: 100%;
        overflow-x: auto;
        -webkit-overflow-scrolling: touch;
    }

    .table-responsive>.table-bordered {
        border: 0;
    }
    th{
        text-align: center;
    }
</style>

@endsection
@section('transaction')
active
@endsection
@section('sales-invoice')
active
@endsection
@section('content')
<div class="wrapper wrapper-content animated fadeInRight">

    @include('errors.list')

    <div class="row wrapper white-bg page-heading">
        <div class="col-md-12">
            <a href="/transactions/sales-invoices/create" class="btn btn-primary pull-right"><i class="fa fa-plus" aria-hidden="true"></i> Create Sales Invoice</a>
        </div>
        @if(count($sales_invoices) != 0)
        <div class="col-md-12">
            <div class="card strpied-tabled-with-hover" style="padding-top: 20px;">
                <div class="card-body">
                    <div class="table-responsive">
                        <table class="table table-striped table-bordered table-hover dt-responsive" >
                        <thead>
                        <tr>
                            <th>Invoice No</th>
                            <th>Date</th>
                            <th>Total Amount</th>
                            <th>Account Name</th>
                            <th>Action</th>
                        </tr>
                        </thead>
                        <tbody>
                            @foreach($sales_invoices as $sales_invoice)
                            <tr>
                                <td>{{ $sales_invoice->invoice_no }}</td>
                                <td>{{ $sales_invoice->date }}</td>
                                <td>{{ $sales_invoice->net_total }}</td>
                                <td>{{ $sales_invoice->account->name_of_organisation }}</td>
                                <td>
                                    @can('view-print-sales-voucher')
                                        <div class="pull-left" style="margin-right: 10px;">
                                            <a href="/transactions/sales-invoices/{{ $sales_invoice->id }}/view" class="btn btn-primary"><i class="fa fa-eye" aria-hidden="true"></i> View</a>
                                        </div>
                                    @endcan
                                    @if ($sales_invoice->deleted_at != "")
                                        <button type="button" class="btn btn-primary"><i class="fa fa-trash" aria-hidden="true"></i> Cancelled</button>
                                    @else
                                        <div class="btn-group">
                                            {{-- @can('view-print-sales-voucher')
                                            <div class="pull-left" style="margin-right: 10px;">
                                                <a href="/transactions/sales-invoices/{{ $sales_invoice->id }}/view" class="btn btn-primary"><i class="fa fa-eye" aria-hidden="true"></i> View</a>
                                            </div>
                                            @endcan --}}
                                            @if ($sales_invoice->paid_amount == 0)
                                                @can('edit-sales-voucher')
                                                <div class="pull-left" style="margin-right: 10px;">
                                                    <a href="/transactions/sales-invoices/{{ $sales_invoice->id }}/edit" class="btn btn-primary"><i class="fa fa-pencil" aria-hidden="true"></i> Edit</a>
                                                </div>
                                                @endcan
                                                {{-- <div class="pull-right">
                                                    <form  method="post" action="/transactions/sales-invoices/{{ $sales_invoice->id }}">
                                                        {{ csrf_field() }}
                                                        {{ method_field('DELETE') }}
                                                        <button type="submit" class="btn btn-primary"><i class="fa fa-trash" aria-hidden="true"></i> Delete</button>
                                                    </form>
                                                </div> --}}
                                                @can('cancel-sales-voucher')
                                                <div class="pull-left" style="margin-right: 10px;">
                                                    <form  method="post" action="/transactions/sales-invoices/{{ $sales_invoice->id }}/softdelete">
                                                        {{ csrf_field() }}
                                                        {{ method_field('DELETE') }}
                                                        <button type="submit" class="btn btn-primary"><i class="fa fa-trash" aria-hidden="true"></i> Cancel</button>
                                                    </form>
                                                </div>
                                                @endcan
                                            @else
                                                <div class="pull-left" style="margin-right: 10px;">
                                                    <button type="button" disabled class="btn btn-primary"><i class="fa fa-pencil" aria-hidden="true"></i> Edit</button>
                                                </div>
                                                <div class="pull-left" style="margin-right: 10px;">
                                                    <button type="button" disabled class="btn btn-primary"><i class="fa fa-trash" aria-hidden="true"></i> Cancel</button>
                                                </div>
                                            @endif
                                            @if ($sales_invoice->is_signed == 1)
                                                <div class="pull-right" style="margin-right: 10px;">
                                                    <a href="/public/user_files/img/client_signs/{{$sales_invoice->signature_path}}" target="blank" type="button" class="btn btn-primary"><i class="fa fa-check"></i> Signed</a>
                                                </div>
                                            @else
                                                <div class="pull-right" style="margin-right: 10px;">
                                                    <a href="/transactions/sales-invoices/signature/{{ $sales_invoice->id }}/create" type="button" class="btn btn-primary"><i class="fa fa-file-text"></i> Signature</a>
                                                </div>
                                            @endif
                                        </div>
                                    @endif
                                </td>
                            </tr>
                            @endforeach
                        </tbody>
                        @if ($sales_invoices->hasPages())
                        <tfoot>
                            <tr>
                                <td colspan="5" class="footable-visible text-center">
                                    {!! $sales_invoices->links() !!}
                                </td>
                            </tr>
                        </tfoot>
                        @endif
                        </table>
                    </div>
                </div>
            </div>
        </div>
        @else
            <h4 style="text-align:center;">No Sale Invoice has been created yet.</h4>
        @endif
    </div>
</div>
@endsection

@section('js')
<script>
    $(document).ready(function(){
        $('.dataTables-sales_invoices').DataTable({
            pageLength: 25,
            dom: '<"html5buttons"B>lTfgitp',
            buttons: [
                { extend: 'copy'},
                {extend: 'csv'},
                {extend: 'excel', title: 'ExampleFile'},
                {extend: 'pdf', title: 'ExampleFile'},

                {extend: 'print',
                 customize: function (win){
                        $(win.document.body).addClass('white-bg');
                        $(win.document.body).css('font-size', '10px');

                        $(win.document.body).find('table')
                                .addClass('compact')
                                .css('font-size', 'inherit');
                }
                }
            ]

        });

    });

</script>
@endsection
